@@ -1,5 +1,6 @@
 use super::StatsigUserLoggable;
 use crate::evaluation::dynamic_value::DynamicValue;
+use crate::hashing::djb2_number;
 use crate::StatsigUser;
 use crate::{evaluation::dynamic_string::DynamicString, Statsig};
 
@@ -32,17 +33,7 @@ impl<'statsig, 'user> StatsigUserInternal<'statsig, 'user> {
     }
 
     pub fn get_unit_id(&self, id_type: &DynamicString) -> Option<&DynamicValue> {
-        if id_type.lowercased_value.eq("userid") {
-            return self.user_ref.data.user_id.as_ref();
-        }
-
-        let custom_ids = self.user_ref.data.custom_ids.as_ref()?;
-
-        if let Some(custom_id) = custom_ids.get(&id_type.value) {
-            return Some(custom_id);
-        }
-
-        custom_ids.get(&id_type.lowercased_value)
+        self.user_ref.get_unit_id(id_type)
     }
 
     pub fn get_user_value(&self, field: &Option<DynamicString>) -> Option<&DynamicValue> {
@@ -70,10 +61,10 @@ impl<'statsig, 'user> StatsigUserInternal<'statsig, 'user> {
         }
 
         if let Some(custom) = &self.user_ref.data.custom {
-            if let Some(found) = custom.get(&field.value) {
+            if let Some(found) = custom.get(field.value.as_str()) {
                 return Some(found);
             }
-            if let Some(lowered_found) = custom.get(lowered_field) {
+            if let Some(lowered_found) = custom.get(lowered_field.as_str()) {
                 return Some(lowered_found);
             }
         }
@@ -90,10 +81,10 @@ impl<'statsig, 'user> StatsigUserInternal<'statsig, 'user> {
         }
 
         if let Some(private_attributes) = &self.user_ref.data.private_attributes {
-            if let Some(found) = private_attributes.get(&field.value) {
+            if let Some(found) = private_attributes.get(field.value.as_str()) {
                 return Some(found);
             }
-            if let Some(lowered_found) = private_attributes.get(lowered_field) {
+            if let Some(lowered_found) = private_attributes.get(lowered_field.as_str()) {
                 return Some(lowered_found);
             }
         }
@@ -137,4 +128,26 @@ impl<'statsig, 'user> StatsigUserInternal<'statsig, 'user> {
 
         StatsigUserLoggable::new(&self.user_ref.data, environment, global_custom)
     }
+
+    pub fn get_hashed_private_attributes(&self) -> Option<String> {
+        let private_attributes = match &self.user_ref.data.private_attributes {
+            Some(attrs) => attrs,
+            None => return None,
+        };
+
+        if private_attributes.is_empty() {
+            return None;
+        }
+
+        let mut val: i64 = 0;
+        for (key, value) in private_attributes {
+            let hash_key = match value.string_value {
+                Some(ref s) => key.to_owned() + ":" + &s.value,
+                None => key.to_owned() + ":",
+            };
+            val += djb2_number(&hash_key);
+            val &= 0xFFFF_FFFF;
+        }
+        Some(val.to_string())
+    }
 }
